#--
#                 - Mellanox Confidential and Proprietary -
# 
# Copyright (C) Dec 2020, Mellanox Technologies Ltd.  ALL RIGHTS RESERVED.
# 
# Except as specifically permitted herein, no portion of the information,
# including but not limited to object code and source code, may be reproduced,
# modified, distributed, republished or otherwise exploited in any form or by
# any means for any purpose without the prior written permission of Mellanox
# Technologies Ltd. Use of software subject to the terms and conditions
# detailed in the file "LICENSE.txt".
#--

import sys
if sys.version_info.major < 3: 
    import commands as sub
else:
    import subprocess as sub
import argparse
#from mtcr import MstDevice

line_card_ids_list= [
    {'id': '0', 'description': 'ALL', 'set_value' : 0x00},
    {'id': '1', 'description': 'LC1', 'set_value' : 0x03},
    {'id': '2', 'description': 'LC2', 'set_value' : 0x04},
    {'id': '3', 'description': 'LC3', 'set_value' : 0x05},
    {'id': '4', 'description': 'LC4', 'set_value' : 0x06},
    {'id': '5', 'description': 'LC5', 'set_value' : 0x07},
    {'id': '6', 'description': 'LC6', 'set_value' : 0x08},
    {'id': '7', 'description': 'LC7', 'set_value' : 0x09},
    {'id': '8', 'description': 'LC8', 'set_value' : 0x0A}
]


def get_value_by_lc_id(lc_id):
    for lc in line_card_ids_list:
        if lc['id'] == lc_id:
            return lc['set_value']


def line_card_ids_options():
    'Return a list with all the ids options'
    return [lc_id['id'] for lc_id in line_card_ids_list]


def run_command(lc_id, image_path):
    value = get_value_by_lc_id(lc_id)

    print ("running iorw command ---")
    cmd_1 = "iorw -w -b 0x2534 -l 1 -v {0}".format(hex(value))
    rc, output = sub.getstatusoutput(cmd_1)

    if rc:
        print ("-E- failed cmd_1. \n{0}".format(output))
        exit()
    
    print ("running cpldupdate command ---")
    cmd_2 = "cpldupdate --gpio {0}".format(image_path)
    rc, output = sub.getstatusoutput(cmd_2)
    if rc: 
        print ("-E- cmd_2 failed.\n {0}".format(output))
        exit()
    else:
        print ("passed for LC={0}".format(lc_id))


def parse():
    parser = argparse.ArgumentParser(description='parse input')
    parser.add_argument('-l',
                         '--lc',
                         action="store",
                         required=True,
                         dest="lc_id",
                         choices=line_card_ids_options(),
                         help='Line card index in hex 1-8')
    parser.add_argument('-i',
                        '--image',
                        action="store",
                        required=True,
                        dest="image_path",
                        help='image to burn full path')
    args = parser.parse_args()
    return args.lc_id, args.image_path


if __name__ == '__main__':
    lc_id, image_path = parse()

    # run for all LCs   
    if (lc_id == 0):
        for id in range(1,9):
            run_command(id, image_path)
    else:
        run_command(lc_id, image_path)